==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/HubSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HubSourceBuilder extends io.fabric8.openshift.api.model.HubSourceFluentImpl<io.fabric8.openshift.api.model.HubSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.HubSource,io.fabric8.openshift.api.model.HubSourceBuilder>{
  public HubSourceBuilder() {
    this(false);
  }
  public HubSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new HubSource(), validationEnabled);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HubSource(), validationEnabled);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent,io.fabric8.openshift.api.model.HubSource instance) {
    this(fluent, instance, false);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent,io.fabric8.openshift.api.model.HubSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDisabled(instance.getDisabled()); 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSource instance) {
    this(instance,false);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDisabled(instance.getDisabled()); 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.HubSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.HubSource build() {
    HubSource buildable = new HubSource(fluent.getDisabled(),fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HubSourceBuilder that = (HubSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/HubSourceBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HubSourceBuilder extends io.fabric8.openshift.api.model.HubSourceFluentImpl<io.fabric8.openshift.api.model.HubSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.HubSource,io.fabric8.openshift.api.model.HubSourceBuilder>{
  public HubSourceBuilder() {
    this(false);
  }
  public HubSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new HubSource(), validationEnabled);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HubSource(), validationEnabled);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent,io.fabric8.openshift.api.model.HubSource instance) {
    this(fluent, instance, false);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSourceFluent<?> fluent,io.fabric8.openshift.api.model.HubSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDisabled(instance.getDisabled()); 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSource instance) {
    this(instance,false);
  }
  public HubSourceBuilder(io.fabric8.openshift.api.model.HubSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDisabled(instance.getDisabled()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.HubSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.HubSource build() {
    HubSource buildable = new HubSource(fluent.getDisabled(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HubSourceBuilder that = (HubSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
